teiid SVN: r2865 - branches/7.1.x/engine/src/test/java/org/teiid/query/unittest.
by teiid-commits@lists.jboss.org
Author: shawkins
Date: 2011-01-20 19:55:36 -0500 (Thu, 20 Jan 2011)
New Revision: 2865
Modified:
branches/7.1.x/engine/src/test/java/org/teiid/query/unittest/RealMetadataFactory.java
Log:
TEIID-1443 adding a better check for getupdated/getdeleted
Modified: branches/7.1.x/engine/src/test/java/org/teiid/query/unittest/RealMetadataFactory.java
===================================================================
--- branches/7.1.x/connectors/translator-salesforce/src/main/java/org/teiid/translator/salesforce/execution/ProcedureExecutionParentImpl.java 2011-01-20 19:57:51 UTC (rev 2863)
+++ branches/7.1.x/connectors/translator-salesforce/src/main/java/org/teiid/translator/salesforce/execution/ProcedureExecutionParentImpl.java 2011-01-20 21:09:35 UTC (rev 2864)
@@ -49,14 +49,14 @@
@Override
public void execute() throws TranslatorException {
- if(getCommand().getProcedureName().endsWith("getUpdated")) {
+ if("GetUpdated".equalsIgnoreCase(getCommand().getMetadataObject().getNameInSource())) { //$NON-NLS-1$
execution = new GetUpdatedExecutionImpl(this);
- execution.execute(this);
- }
- else if(getCommand().getProcedureName().endsWith("getDeleted")) {
+ } else if("GetDeleted".equalsIgnoreCase(getCommand().getMetadataObject().getNameInSource())) { //$NON-NLS-1$
execution = new GetDeletedExecutionImpl(this);
- execution.execute(this);
+ } else {
+ throw new AssertionError("Unknown procedure " + getCommand().getProcedureName() + " with name in source " + getCommand().getMetadataObject().getNameInSource()); //$NON-NLS-1$ //$NON-NLS-2$
}
+ execution.execute(this);
}
public void setCommand(Call command) {
Added: branches/7.1.x/connectors/translator-salesforce/src/test/java/org/teiid/translator/salesforce/execution/TestProcedureExecution.java
===================================================================
--- branches/7.1.x/connectors/translator-salesforce/src/test/java/org/teiid/translator/salesforce/execution/TestProcedureExecution.java (rev 0)
+++ branches/7.1.x/connectors/translator-salesforce/src/test/java/org/teiid/translator/salesforce/execution/TestProcedureExecution.java 2011-01-20 21:09:35 UTC (rev 2864)
@@ -0,0 +1,59 @@
+/*
+ * JBoss, Home of Professional Open Source.
+ * See the COPYRIGHT.txt file distributed with this work for information
+ * regarding copyright ownership. Some portions may be licensed
+ * to Red Hat, Inc. under one or more contributor license agreements.
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ */
+
+package org.teiid.translator.salesforce.execution;
+
+import static org.junit.Assert.*;
+
+import java.util.Arrays;
+
+import javax.xml.datatype.XMLGregorianCalendar;
+
+import org.junit.Test;
+import org.mockito.Mockito;
+import org.teiid.cdk.api.TranslationUtility;
+import org.teiid.language.Call;
+import org.teiid.metadata.RuntimeMetadata;
+import org.teiid.translator.ExecutionContext;
+import org.teiid.translator.salesforce.SalesforceConnection;
+import org.teiid.translator.salesforce.execution.visitors.TestVisitors;
+
+@SuppressWarnings("nls")
+public class TestProcedureExecution {
+
+ private static TranslationUtility translationUtility = new TranslationUtility(TestVisitors.exampleSalesforce());
+
+ @Test public void testProcedureName() throws Exception {
+ Call command = (Call)translationUtility.parseCommand("exec getupdated('foo', {d '1970-01-01'}, {d '1990-01-01'})"); //$NON-NLS-1$
+ SalesforceConnection sfc = Mockito.mock(SalesforceConnection.class);
+ UpdatedResult ur = new UpdatedResult();
+ ur.setIDs(Arrays.asList("1", "2"));
+ Mockito.stub(sfc.getUpdated(Mockito.eq("foo"), (XMLGregorianCalendar)Mockito.anyObject(), (XMLGregorianCalendar)Mockito.anyObject())).toReturn(ur);
+ ProcedureExecutionParentImpl pepi = new ProcedureExecutionParentImpl(command, sfc, Mockito.mock(RuntimeMetadata.class), Mockito.mock(ExecutionContext.class));
+ pepi.execute();
+ assertNotNull(pepi.next());
+ assertNotNull(pepi.next());
+ assertNull(pepi.next());
+ pepi.close();
+ }
+
+}
Property changes on: branches/7.1.x/connectors/translator-salesforce/src/test/java/org/teiid/translator/salesforce/execution/TestProcedureExecution.java
___________________________________________________________________
Name: svn:mime-type
+ text/plain
Modified: branches/7.1.x/connectors/translator-salesforce/src/test/java/org/teiid/translator/salesforce/execution/visitors/TestVisitors.java
===================================================================
--- branches/7.1.x/connectors/translator-salesforce/src/test/java/org/teiid/translator/salesforce/execution/visitors/TestVisitors.java 2011-01-20 19:57:51 UTC (rev 2863)
+++ branches/7.1.x/connectors/translator-salesforce/src/test/java/org/teiid/translator/salesforce/execution/visitors/TestVisitors.java 2011-01-20 21:09:35 UTC (rev 2864)
@@ -24,6 +24,7 @@
import static org.junit.Assert.*;
import java.util.Arrays;
+import java.util.LinkedList;
import java.util.List;
import java.util.TimeZone;
@@ -34,15 +35,19 @@
import org.teiid.language.Select;
import org.teiid.metadata.Column;
import org.teiid.metadata.MetadataStore;
+import org.teiid.metadata.Procedure;
+import org.teiid.metadata.ProcedureParameter;
import org.teiid.metadata.Schema;
import org.teiid.metadata.Table;
import org.teiid.metadata.Column.SearchType;
import org.teiid.query.metadata.CompositeMetadataStore;
import org.teiid.query.metadata.QueryMetadataInterface;
import org.teiid.query.metadata.TransformationMetadata;
+import org.teiid.query.sql.lang.SPParameter;
import org.teiid.query.unittest.FakeMetadataFactory;
import org.teiid.query.unittest.RealMetadataFactory;
import org.teiid.translator.ExecutionContext;
+import org.teiid.translator.TypeFacility;
import org.teiid.translator.salesforce.Constants;
import org.teiid.translator.salesforce.SalesforceConnection;
import org.teiid.translator.salesforce.execution.QueryExecutionImpl;
@@ -101,6 +106,15 @@
Column obj = contactCols.get(i);
obj.setNameInSource(contactNameInSource[i]);
}
+
+ List<ProcedureParameter> params = new LinkedList<ProcedureParameter>();
+ params.add(RealMetadataFactory.createParameter("type", SPParameter.IN, TypeFacility.RUNTIME_NAMES.STRING));
+ params.add(RealMetadataFactory.createParameter("start", SPParameter.IN, TypeFacility.RUNTIME_NAMES.TIMESTAMP));
+ params.add(RealMetadataFactory.createParameter("end", SPParameter.IN, TypeFacility.RUNTIME_NAMES.TIMESTAMP));
+
+ Procedure getUpdated = RealMetadataFactory.createStoredProcedure("GetUpdated", salesforceModel, params, "GetUpdated");
+ getUpdated.setResultSet(RealMetadataFactory.createResultSet("rs", new String[] {"updated"}, new String[] {TypeFacility.RUNTIME_NAMES.STRING}));
+
return new TransformationMetadata(null, new CompositeMetadataStore(store), null, null, FakeMetadataFactory.SFM.getSystemFunctions());
}
15 years, 2 months
teiid SVN: r2863 - in branches/7.3.x: connectors/translator-salesforce/src/test/java/org/teiid/translator/salesforce/execution and 2 other directories.
by teiid-commits@lists.jboss.org
Author: shawkins
Date: 2011-01-20 14:57:51 -0500 (Thu, 20 Jan 2011)
New Revision: 2863
Added:
branches/7.3.x/connectors/translator-salesforce/src/test/java/org/teiid/translator/salesforce/execution/TestProcedureExecution.java
Modified:
branches/7.3.x/connectors/translator-salesforce/src/main/java/org/teiid/translator/salesforce/execution/ProcedureExecutionParentImpl.java
branches/7.3.x/connectors/translator-salesforce/src/test/java/org/teiid/translator/salesforce/execution/visitors/TestVisitors.java
branches/7.3.x/engine/src/test/java/org/teiid/query/unittest/RealMetadataFactory.java
Log:
TEIID-1443 adding a better check for procedure names
Modified: branches/7.3.x/connectors/translator-salesforce/src/main/java/org/teiid/translator/salesforce/execution/ProcedureExecutionParentImpl.java
===================================================================
--- branches/7.3.x/connectors/translator-salesforce/src/main/java/org/teiid/translator/salesforce/execution/ProcedureExecutionParentImpl.java 2011-01-20 15:28:34 UTC (rev 2862)
+++ branches/7.3.x/connectors/translator-salesforce/src/main/java/org/teiid/translator/salesforce/execution/ProcedureExecutionParentImpl.java 2011-01-20 19:57:51 UTC (rev 2863)
@@ -71,14 +71,14 @@
@Override
public void execute() throws TranslatorException {
- if(getCommand().getProcedureName().endsWith("getUpdated")) {
+ if("GetUpdated".equalsIgnoreCase(getCommand().getMetadataObject().getNameInSource())) { //$NON-NLS-1$
execution = new GetUpdatedExecutionImpl(this);
- execution.execute(this);
- }
- else if(getCommand().getProcedureName().endsWith("getDeleted")) {
+ } else if("GetDeleted".equalsIgnoreCase(getCommand().getMetadataObject().getNameInSource())) { //$NON-NLS-1$
execution = new GetDeletedExecutionImpl(this);
- execution.execute(this);
+ } else {
+ throw new AssertionError("Unknown procedure " + getCommand().getProcedureName() + " with name in source " + getCommand().getMetadataObject().getNameInSource()); //$NON-NLS-1$ //$NON-NLS-2$
}
+ execution.execute(this);
}
public void setCommand(Call command) {
Added: branches/7.3.x/connectors/translator-salesforce/src/test/java/org/teiid/translator/salesforce/execution/TestProcedureExecution.java
===================================================================
--- branches/7.3.x/connectors/translator-salesforce/src/test/java/org/teiid/translator/salesforce/execution/TestProcedureExecution.java (rev 0)
+++ branches/7.3.x/connectors/translator-salesforce/src/test/java/org/teiid/translator/salesforce/execution/TestProcedureExecution.java 2011-01-20 19:57:51 UTC (rev 2863)
@@ -0,0 +1,60 @@
+/*
+ * JBoss, Home of Professional Open Source.
+ * See the COPYRIGHT.txt file distributed with this work for information
+ * regarding copyright ownership. Some portions may be licensed
+ * to Red Hat, Inc. under one or more contributor license agreements.
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ */
+
+package org.teiid.translator.salesforce.execution;
+
+import static org.junit.Assert.*;
+
+import java.math.BigDecimal;
+import java.util.Arrays;
+
+import javax.xml.datatype.XMLGregorianCalendar;
+
+import org.junit.Test;
+import org.mockito.Mockito;
+import org.teiid.cdk.api.TranslationUtility;
+import org.teiid.language.Call;
+import org.teiid.metadata.RuntimeMetadata;
+import org.teiid.translator.ExecutionContext;
+import org.teiid.translator.salesforce.SalesforceConnection;
+import org.teiid.translator.salesforce.execution.visitors.TestVisitors;
+
+@SuppressWarnings("nls")
+public class TestProcedureExecution {
+
+ private static TranslationUtility translationUtility = new TranslationUtility(TestVisitors.exampleSalesforce());
+
+ @Test public void testProcedureName() throws Exception {
+ Call command = (Call)translationUtility.parseCommand("exec getupdated('foo', {d '1970-01-01'}, {d '1990-01-01'})"); //$NON-NLS-1$
+ SalesforceConnection sfc = Mockito.mock(SalesforceConnection.class);
+ UpdatedResult ur = new UpdatedResult();
+ ur.setIDs(Arrays.asList("1", "2"));
+ Mockito.stub(sfc.getUpdated(Mockito.eq("foo"), (XMLGregorianCalendar)Mockito.anyObject(), (XMLGregorianCalendar)Mockito.anyObject())).toReturn(ur);
+ ProcedureExecutionParentImpl pepi = new ProcedureExecutionParentImpl(command, sfc, Mockito.mock(RuntimeMetadata.class), Mockito.mock(ExecutionContext.class));
+ pepi.execute();
+ assertNotNull(pepi.next());
+ assertNotNull(pepi.next());
+ assertNull(pepi.next());
+ pepi.close();
+ }
+
+}
Property changes on: branches/7.3.x/connectors/translator-salesforce/src/test/java/org/teiid/translator/salesforce/execution/TestProcedureExecution.java
___________________________________________________________________
Name: svn:mime-type
+ text/plain
Modified: branches/7.3.x/connectors/translator-salesforce/src/test/java/org/teiid/translator/salesforce/execution/visitors/TestVisitors.java
===================================================================
--- branches/7.3.x/connectors/translator-salesforce/src/test/java/org/teiid/translator/salesforce/execution/visitors/TestVisitors.java 2011-01-20 15:28:34 UTC (rev 2862)
+++ branches/7.3.x/connectors/translator-salesforce/src/test/java/org/teiid/translator/salesforce/execution/visitors/TestVisitors.java 2011-01-20 19:57:51 UTC (rev 2863)
@@ -24,6 +24,7 @@
import static org.junit.Assert.*;
import java.util.Arrays;
+import java.util.LinkedList;
import java.util.List;
import java.util.TimeZone;
@@ -34,15 +35,19 @@
import org.teiid.language.Select;
import org.teiid.metadata.Column;
import org.teiid.metadata.MetadataStore;
+import org.teiid.metadata.Procedure;
+import org.teiid.metadata.ProcedureParameter;
import org.teiid.metadata.Schema;
import org.teiid.metadata.Table;
import org.teiid.metadata.Column.SearchType;
import org.teiid.query.metadata.CompositeMetadataStore;
import org.teiid.query.metadata.QueryMetadataInterface;
import org.teiid.query.metadata.TransformationMetadata;
+import org.teiid.query.sql.lang.SPParameter;
import org.teiid.query.unittest.FakeMetadataFactory;
import org.teiid.query.unittest.RealMetadataFactory;
import org.teiid.translator.ExecutionContext;
+import org.teiid.translator.TypeFacility;
import org.teiid.translator.salesforce.Constants;
import org.teiid.translator.salesforce.SalesforceConnection;
import org.teiid.translator.salesforce.execution.QueryExecutionImpl;
@@ -101,6 +106,14 @@
Column obj = contactCols.get(i);
obj.setNameInSource(contactNameInSource[i]);
}
+ List<ProcedureParameter> params = new LinkedList<ProcedureParameter>();
+ params.add(RealMetadataFactory.createParameter("type", SPParameter.IN, TypeFacility.RUNTIME_NAMES.STRING));
+ params.add(RealMetadataFactory.createParameter("start", SPParameter.IN, TypeFacility.RUNTIME_NAMES.TIMESTAMP));
+ params.add(RealMetadataFactory.createParameter("end", SPParameter.IN, TypeFacility.RUNTIME_NAMES.TIMESTAMP));
+
+ Procedure getUpdated = RealMetadataFactory.createStoredProcedure("GetUpdated", salesforceModel, params, "GetUpdated");
+ getUpdated.setResultSet(RealMetadataFactory.createResultSet("rs", new String[] {"updated"}, new String[] {TypeFacility.RUNTIME_NAMES.STRING}));
+
return new TransformationMetadata(null, new CompositeMetadataStore(store), null, FakeMetadataFactory.SFM.getSystemFunctions(), null);
}
Modified: branches/7.3.x/engine/src/test/java/org/teiid/query/unittest/RealMetadataFactory.java
===================================================================
--- branches/7.1.x/console/src/main/resources/META-INF/rhq-plugin.xml 2011-01-19 20:56:59 UTC (rev 2861)
+++ branches/7.1.x/console/src/main/resources/META-INF/rhq-plugin.xml 2011-01-20 15:28:34 UTC (rev 2862)
@@ -512,7 +512,7 @@
</operation>
<operation name="reloadMaterializedView" displayName="Refresh a Materialized View"
- description="Refresh a given any Materialized View for this VDB">
+ description="Refresh a given Materialized View for this VDB">
<parameters>
<c:simple-property displayName="Materialized View Schema"
name="schema" type="string" required="true"
15 years, 2 months
teiid SVN: r2861 - trunk/build/kits/jboss-container.
by teiid-commits@lists.jboss.org
Author: shawkins
Date: 2011-01-19 15:56:59 -0500 (Wed, 19 Jan 2011)
New Revision: 2861
Modified:
trunk/build/kits/jboss-container/teiid-releasenotes.html
Log:
TEIID-1008 marking deeply nested correlated reference handling as a KI
Modified: trunk/build/kits/jboss-container/teiid-releasenotes.html
===================================================================
--- trunk/build/kits/jboss-container/teiid-releasenotes.html 2011-01-19 20:55:32 UTC (rev 2860)
+++ trunk/build/kits/jboss-container/teiid-releasenotes.html 2011-01-19 20:56:59 UTC (rev 2861)
@@ -137,6 +137,7 @@
<h2><a name="Other">Other Issues</a></h2>
<ul>
+ <li>TEIID-1008 - Most versions of Oracle and MySQL do not support deeply nested correlated references. There is currently no workaround for this issue.
<li>For compatibility with the 7.0 release if a stored procedure parameter list begins with identifier=, then it will be parsed as a named parameter invocation even if the intent was to use a comparison predicate
as the first parameter value. The workaround is to use nesting parens, e.g. call proc((identifier=value), ...), which clarifies that this is positional value. This workaround will not be needed in later releases.
</ul>
15 years, 2 months
teiid SVN: r2860 - in trunk: adminshell and 37 other directories.
by teiid-commits@lists.jboss.org
Author: shawkins
Date: 2011-01-19 15:55:32 -0500 (Wed, 19 Jan 2011)
New Revision: 2860
Modified:
trunk/adminshell/pom.xml
trunk/api/pom.xml
trunk/build/kits/jboss-container/COPYRIGHT.txt
trunk/build/pom.xml
trunk/cache-jbosscache/pom.xml
trunk/client/pom.xml
trunk/common-core/pom.xml
trunk/connectors/connector-file/pom.xml
trunk/connectors/connector-ldap/pom.xml
trunk/connectors/connector-salesforce/pom.xml
trunk/connectors/connector-ws/pom.xml
trunk/connectors/pom.xml
trunk/connectors/salesforce-api/pom.xml
trunk/connectors/sandbox/pom.xml
trunk/connectors/sandbox/translator-yahoo/pom.xml
trunk/connectors/translator-file/pom.xml
trunk/connectors/translator-jdbc/pom.xml
trunk/connectors/translator-ldap/pom.xml
trunk/connectors/translator-loopback/pom.xml
trunk/connectors/translator-salesforce/pom.xml
trunk/connectors/translator-ws/pom.xml
trunk/console/pom.xml
trunk/documentation/admin-guide/pom.xml
trunk/documentation/caching-guide/pom.xml
trunk/documentation/client-developers-guide/pom.xml
trunk/documentation/developer-guide/pom.xml
trunk/documentation/docbook/custom.dtd
trunk/documentation/pom.xml
trunk/documentation/quick-start-example/pom.xml
trunk/documentation/reference/pom.xml
trunk/engine/pom.xml
trunk/hibernate-dialect/pom.xml
trunk/jboss-integration/pom.xml
trunk/metadata/pom.xml
trunk/pom.xml
trunk/runtime/pom.xml
trunk/test-integration/common/pom.xml
trunk/test-integration/db/pom.xml
trunk/test-integration/pom.xml
Log:
switching trunk to 7.4
Modified: trunk/adminshell/pom.xml
===================================================================
--- trunk/adminshell/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/adminshell/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -3,7 +3,7 @@
<parent>
<artifactId>teiid-parent</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>teiid-adminshell</artifactId>
Modified: trunk/api/pom.xml
===================================================================
--- trunk/api/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/api/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -3,7 +3,7 @@
<parent>
<artifactId>teiid-parent</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>teiid-api</artifactId>
Modified: trunk/build/kits/jboss-container/COPYRIGHT.txt
===================================================================
--- trunk/build/kits/jboss-container/COPYRIGHT.txt 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/build/kits/jboss-container/COPYRIGHT.txt 2011-01-19 20:55:32 UTC (rev 2860)
@@ -1,4 +1,4 @@
-Portions Copyright (C) 2008-2009 Red Hat, Inc.
+Portions Copyright (C) 2008-2011 Red Hat, Inc.
Portions Copyright (C) 2000-2007 MetaMatrix, Inc.
Portions Copyright (c) 2000, 2003, 2008 IBM Corporation and others.
Portions Copyright (c) 1997-2000 Sun Microsystems, Inc.
\ No newline at end of file
Modified: trunk/build/pom.xml
===================================================================
--- trunk/build/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/build/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -2,7 +2,7 @@
<parent>
<artifactId>teiid-parent</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>teiid</artifactId>
Modified: trunk/cache-jbosscache/pom.xml
===================================================================
--- trunk/cache-jbosscache/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/cache-jbosscache/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -3,7 +3,7 @@
<parent>
<artifactId>teiid-parent</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>teiid-cache-jbosscache</artifactId>
Modified: trunk/client/pom.xml
===================================================================
--- trunk/client/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/client/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -3,7 +3,7 @@
<parent>
<artifactId>teiid-parent</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>teiid-client</artifactId>
Modified: trunk/common-core/pom.xml
===================================================================
--- trunk/common-core/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/common-core/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -3,7 +3,7 @@
<parent>
<artifactId>teiid-parent</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>teiid-common-core</artifactId>
Modified: trunk/connectors/connector-file/pom.xml
===================================================================
--- trunk/connectors/connector-file/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/connectors/connector-file/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -3,7 +3,7 @@
<parent>
<artifactId>connectors</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>connector-file</artifactId>
Modified: trunk/connectors/connector-ldap/pom.xml
===================================================================
--- trunk/connectors/connector-ldap/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/connectors/connector-ldap/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -2,7 +2,7 @@
<parent>
<artifactId>connectors</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>connector-ldap</artifactId>
Modified: trunk/connectors/connector-salesforce/pom.xml
===================================================================
--- trunk/connectors/connector-salesforce/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/connectors/connector-salesforce/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -3,7 +3,7 @@
<parent>
<artifactId>connectors</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>connector-salesforce</artifactId>
Modified: trunk/connectors/connector-ws/pom.xml
===================================================================
--- trunk/connectors/connector-ws/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/connectors/connector-ws/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -3,7 +3,7 @@
<parent>
<artifactId>connectors</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>connector-ws</artifactId>
Modified: trunk/connectors/pom.xml
===================================================================
--- trunk/connectors/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/connectors/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -3,7 +3,7 @@
<parent>
<artifactId>teiid-parent</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<groupId>org.jboss.teiid</groupId>
Modified: trunk/connectors/salesforce-api/pom.xml
===================================================================
--- trunk/connectors/salesforce-api/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/connectors/salesforce-api/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -2,7 +2,7 @@
<parent>
<artifactId>connectors</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>salesforce-api</artifactId>
Modified: trunk/connectors/sandbox/pom.xml
===================================================================
--- trunk/connectors/sandbox/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/connectors/sandbox/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -3,7 +3,7 @@
<parent>
<artifactId>connectors</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<groupId>org.jboss.teiid.connectors</groupId>
Modified: trunk/connectors/sandbox/translator-yahoo/pom.xml
===================================================================
--- trunk/connectors/sandbox/translator-yahoo/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/connectors/sandbox/translator-yahoo/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -3,7 +3,7 @@
<parent>
<artifactId>sandbox</artifactId>
<groupId>org.jboss.teiid.connectors</groupId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>translator-yahoo</artifactId>
Modified: trunk/connectors/translator-file/pom.xml
===================================================================
--- trunk/connectors/translator-file/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/connectors/translator-file/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -3,7 +3,7 @@
<parent>
<artifactId>connectors</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>translator-file</artifactId>
Modified: trunk/connectors/translator-jdbc/pom.xml
===================================================================
--- trunk/connectors/translator-jdbc/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/connectors/translator-jdbc/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -3,7 +3,7 @@
<parent>
<artifactId>connectors</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>translator-jdbc</artifactId>
Modified: trunk/connectors/translator-ldap/pom.xml
===================================================================
--- trunk/connectors/translator-ldap/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/connectors/translator-ldap/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -2,7 +2,7 @@
<parent>
<artifactId>connectors</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>translator-ldap</artifactId>
Modified: trunk/connectors/translator-loopback/pom.xml
===================================================================
--- trunk/connectors/translator-loopback/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/connectors/translator-loopback/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -3,7 +3,7 @@
<parent>
<artifactId>connectors</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>translator-loopback</artifactId>
Modified: trunk/connectors/translator-salesforce/pom.xml
===================================================================
--- trunk/connectors/translator-salesforce/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/connectors/translator-salesforce/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -3,7 +3,7 @@
<parent>
<artifactId>connectors</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>translator-salesforce</artifactId>
Modified: trunk/connectors/translator-ws/pom.xml
===================================================================
--- trunk/connectors/translator-ws/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/connectors/translator-ws/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -3,7 +3,7 @@
<parent>
<artifactId>connectors</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>translator-ws</artifactId>
Modified: trunk/console/pom.xml
===================================================================
--- trunk/console/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/console/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -3,7 +3,7 @@
<parent>
<artifactId>teiid-parent</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
Modified: trunk/documentation/admin-guide/pom.xml
===================================================================
--- trunk/documentation/admin-guide/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/documentation/admin-guide/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -2,7 +2,7 @@
<parent>
<groupId>org.jboss.teiid</groupId>
<artifactId>documentation</artifactId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>admin-guide</artifactId>
Modified: trunk/documentation/caching-guide/pom.xml
===================================================================
--- trunk/documentation/caching-guide/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/documentation/caching-guide/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -2,7 +2,7 @@
<parent>
<groupId>org.jboss.teiid</groupId>
<artifactId>documentation</artifactId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>caching-guide</artifactId>
Modified: trunk/documentation/client-developers-guide/pom.xml
===================================================================
--- trunk/documentation/client-developers-guide/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/documentation/client-developers-guide/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -2,7 +2,7 @@
<parent>
<groupId>org.jboss.teiid</groupId>
<artifactId>documentation</artifactId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>client-developers-guide</artifactId>
Modified: trunk/documentation/developer-guide/pom.xml
===================================================================
--- trunk/documentation/developer-guide/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/documentation/developer-guide/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -2,7 +2,7 @@
<parent>
<groupId>org.jboss.teiid</groupId>
<artifactId>documentation</artifactId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>developer-guide</artifactId>
Modified: trunk/documentation/docbook/custom.dtd
===================================================================
--- trunk/documentation/docbook/custom.dtd 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/documentation/docbook/custom.dtd 2011-01-19 20:55:32 UTC (rev 2860)
@@ -1,5 +1,5 @@
-<!ENTITY versionNumber "7.3">
-<!ENTITY copyrightYear "2009">
+<!ENTITY versionNumber "7.4">
+<!ENTITY copyrightYear "2011">
<!ENTITY copyrightHolder "Red Hat, Inc.">
<!ENTITY url "http://www.jboss.org/teiid/">
<!ENTITY docUrl "&url;/docs.html">
Modified: trunk/documentation/pom.xml
===================================================================
--- trunk/documentation/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/documentation/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -2,7 +2,7 @@
<parent>
<artifactId>teiid-parent</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<groupId>org.jboss.teiid</groupId>
Modified: trunk/documentation/quick-start-example/pom.xml
===================================================================
--- trunk/documentation/quick-start-example/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/documentation/quick-start-example/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -2,7 +2,7 @@
<parent>
<groupId>org.jboss.teiid</groupId>
<artifactId>documentation</artifactId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>quick-start-example</artifactId>
Modified: trunk/documentation/reference/pom.xml
===================================================================
--- trunk/documentation/reference/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/documentation/reference/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -2,7 +2,7 @@
<parent>
<groupId>org.jboss.teiid</groupId>
<artifactId>documentation</artifactId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>reference</artifactId>
Modified: trunk/engine/pom.xml
===================================================================
--- trunk/engine/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/engine/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -3,7 +3,7 @@
<parent>
<artifactId>teiid-parent</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>teiid-engine</artifactId>
Modified: trunk/hibernate-dialect/pom.xml
===================================================================
--- trunk/hibernate-dialect/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/hibernate-dialect/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -2,7 +2,7 @@
<parent>
<artifactId>teiid-parent</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>teiid-hibernate-dialect</artifactId>
Modified: trunk/jboss-integration/pom.xml
===================================================================
--- trunk/jboss-integration/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/jboss-integration/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -2,7 +2,7 @@
<parent>
<artifactId>teiid-parent</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<groupId>org.jboss.teiid</groupId>
Modified: trunk/metadata/pom.xml
===================================================================
--- trunk/metadata/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/metadata/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -3,7 +3,7 @@
<parent>
<artifactId>teiid-parent</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>teiid-metadata</artifactId>
Modified: trunk/pom.xml
===================================================================
--- trunk/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -5,7 +5,7 @@
<artifactId>teiid-parent</artifactId>
<packaging>pom</packaging>
<name>Teiid</name>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
<description>Federated SQL and XML query engine.</description>
<properties>
<ant.version>1.7.0</ant.version>
Modified: trunk/runtime/pom.xml
===================================================================
--- trunk/runtime/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/runtime/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -3,7 +3,7 @@
<parent>
<artifactId>teiid-parent</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<groupId>org.jboss.teiid</groupId>
Modified: trunk/test-integration/common/pom.xml
===================================================================
--- trunk/test-integration/common/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/test-integration/common/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -3,7 +3,7 @@
<parent>
<artifactId>teiid-test-integration</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>test-integration-common</artifactId>
Modified: trunk/test-integration/db/pom.xml
===================================================================
--- trunk/test-integration/db/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/test-integration/db/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -9,7 +9,7 @@
<parent>
<artifactId>teiid-test-integration</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
Modified: trunk/test-integration/pom.xml
===================================================================
--- trunk/test-integration/pom.xml 2011-01-19 20:31:00 UTC (rev 2859)
+++ trunk/test-integration/pom.xml 2011-01-19 20:55:32 UTC (rev 2860)
@@ -3,7 +3,7 @@
<parent>
<artifactId>teiid-parent</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR2-SNAPSHOT</version>
+ <version>7.4.0.Alpha1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>teiid-test-integration</artifactId>
15 years, 2 months
teiid SVN: r2859 - /.
by teiid-commits@lists.jboss.org
Author: rareddy
Date: 2011-01-19 15:31:00 -0500 (Wed, 19 Jan 2011)
New Revision: 2859
Removed:
7.3.x/
Log:
wrong location
15 years, 2 months
teiid SVN: r2858 - branches.
by teiid-commits@lists.jboss.org
Author: rareddy
Date: 2011-01-19 15:27:10 -0500 (Wed, 19 Jan 2011)
New Revision: 2858
Added:
branches/7.3.x/
Log:
branch for remaining 7.3 work
Copied: branches/7.3.x (from rev 2857, trunk)
15 years, 2 months
teiid SVN: r2857 - /.
by teiid-commits@lists.jboss.org
Author: rareddy
Date: 2011-01-19 15:23:50 -0500 (Wed, 19 Jan 2011)
New Revision: 2857
Added:
7.3.x/
Log:
branch for remaining 7.3 work
Copied: 7.3.x (from rev 2856, trunk)
15 years, 2 months
teiid SVN: r2856 - in trunk: adminshell and 35 other directories.
by teiid-commits@lists.jboss.org
Author: rareddy
Date: 2011-01-19 12:13:44 -0500 (Wed, 19 Jan 2011)
New Revision: 2856
Modified:
trunk/adminshell/pom.xml
trunk/api/pom.xml
trunk/build/pom.xml
trunk/cache-jbosscache/pom.xml
trunk/client/pom.xml
trunk/common-core/pom.xml
trunk/connectors/connector-file/pom.xml
trunk/connectors/connector-ldap/pom.xml
trunk/connectors/connector-salesforce/pom.xml
trunk/connectors/connector-ws/pom.xml
trunk/connectors/pom.xml
trunk/connectors/salesforce-api/pom.xml
trunk/connectors/sandbox/pom.xml
trunk/connectors/sandbox/translator-yahoo/pom.xml
trunk/connectors/translator-file/pom.xml
trunk/connectors/translator-jdbc/pom.xml
trunk/connectors/translator-ldap/pom.xml
trunk/connectors/translator-loopback/pom.xml
trunk/connectors/translator-salesforce/pom.xml
trunk/connectors/translator-ws/pom.xml
trunk/console/pom.xml
trunk/documentation/admin-guide/pom.xml
trunk/documentation/caching-guide/pom.xml
trunk/documentation/client-developers-guide/pom.xml
trunk/documentation/developer-guide/pom.xml
trunk/documentation/pom.xml
trunk/documentation/quick-start-example/pom.xml
trunk/documentation/reference/pom.xml
trunk/engine/pom.xml
trunk/hibernate-dialect/pom.xml
trunk/jboss-integration/pom.xml
trunk/metadata/pom.xml
trunk/pom.xml
trunk/runtime/pom.xml
trunk/test-integration/common/pom.xml
trunk/test-integration/db/pom.xml
trunk/test-integration/pom.xml
Log:
[maven-release-plugin] prepare for next development iteration
Modified: trunk/adminshell/pom.xml
===================================================================
--- trunk/adminshell/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/adminshell/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -3,7 +3,7 @@
<parent>
<artifactId>teiid-parent</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>teiid-adminshell</artifactId>
Modified: trunk/api/pom.xml
===================================================================
--- trunk/api/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/api/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -3,7 +3,7 @@
<parent>
<artifactId>teiid-parent</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>teiid-api</artifactId>
Modified: trunk/build/pom.xml
===================================================================
--- trunk/build/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/build/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -2,7 +2,7 @@
<parent>
<artifactId>teiid-parent</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>teiid</artifactId>
Modified: trunk/cache-jbosscache/pom.xml
===================================================================
--- trunk/cache-jbosscache/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/cache-jbosscache/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -3,7 +3,7 @@
<parent>
<artifactId>teiid-parent</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>teiid-cache-jbosscache</artifactId>
Modified: trunk/client/pom.xml
===================================================================
--- trunk/client/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/client/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -3,7 +3,7 @@
<parent>
<artifactId>teiid-parent</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>teiid-client</artifactId>
Modified: trunk/common-core/pom.xml
===================================================================
--- trunk/common-core/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/common-core/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -3,7 +3,7 @@
<parent>
<artifactId>teiid-parent</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>teiid-common-core</artifactId>
Modified: trunk/connectors/connector-file/pom.xml
===================================================================
--- trunk/connectors/connector-file/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/connectors/connector-file/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -3,7 +3,7 @@
<parent>
<artifactId>connectors</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>connector-file</artifactId>
Modified: trunk/connectors/connector-ldap/pom.xml
===================================================================
--- trunk/connectors/connector-ldap/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/connectors/connector-ldap/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -2,7 +2,7 @@
<parent>
<artifactId>connectors</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>connector-ldap</artifactId>
Modified: trunk/connectors/connector-salesforce/pom.xml
===================================================================
--- trunk/connectors/connector-salesforce/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/connectors/connector-salesforce/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -3,7 +3,7 @@
<parent>
<artifactId>connectors</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>connector-salesforce</artifactId>
Modified: trunk/connectors/connector-ws/pom.xml
===================================================================
--- trunk/connectors/connector-ws/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/connectors/connector-ws/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -3,7 +3,7 @@
<parent>
<artifactId>connectors</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>connector-ws</artifactId>
Modified: trunk/connectors/pom.xml
===================================================================
--- trunk/connectors/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/connectors/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -3,7 +3,7 @@
<parent>
<artifactId>teiid-parent</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<groupId>org.jboss.teiid</groupId>
Modified: trunk/connectors/salesforce-api/pom.xml
===================================================================
--- trunk/connectors/salesforce-api/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/connectors/salesforce-api/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -2,7 +2,7 @@
<parent>
<artifactId>connectors</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>salesforce-api</artifactId>
Modified: trunk/connectors/sandbox/pom.xml
===================================================================
--- trunk/connectors/sandbox/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/connectors/sandbox/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -3,7 +3,7 @@
<parent>
<artifactId>connectors</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<groupId>org.jboss.teiid.connectors</groupId>
Modified: trunk/connectors/sandbox/translator-yahoo/pom.xml
===================================================================
--- trunk/connectors/sandbox/translator-yahoo/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/connectors/sandbox/translator-yahoo/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -3,7 +3,7 @@
<parent>
<artifactId>sandbox</artifactId>
<groupId>org.jboss.teiid.connectors</groupId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>translator-yahoo</artifactId>
Modified: trunk/connectors/translator-file/pom.xml
===================================================================
--- trunk/connectors/translator-file/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/connectors/translator-file/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -3,7 +3,7 @@
<parent>
<artifactId>connectors</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>translator-file</artifactId>
Modified: trunk/connectors/translator-jdbc/pom.xml
===================================================================
--- trunk/connectors/translator-jdbc/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/connectors/translator-jdbc/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -3,7 +3,7 @@
<parent>
<artifactId>connectors</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>translator-jdbc</artifactId>
Modified: trunk/connectors/translator-ldap/pom.xml
===================================================================
--- trunk/connectors/translator-ldap/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/connectors/translator-ldap/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -2,7 +2,7 @@
<parent>
<artifactId>connectors</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>translator-ldap</artifactId>
Modified: trunk/connectors/translator-loopback/pom.xml
===================================================================
--- trunk/connectors/translator-loopback/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/connectors/translator-loopback/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -3,7 +3,7 @@
<parent>
<artifactId>connectors</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>translator-loopback</artifactId>
Modified: trunk/connectors/translator-salesforce/pom.xml
===================================================================
--- trunk/connectors/translator-salesforce/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/connectors/translator-salesforce/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -3,7 +3,7 @@
<parent>
<artifactId>connectors</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>translator-salesforce</artifactId>
Modified: trunk/connectors/translator-ws/pom.xml
===================================================================
--- trunk/connectors/translator-ws/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/connectors/translator-ws/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -3,7 +3,7 @@
<parent>
<artifactId>connectors</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>translator-ws</artifactId>
Modified: trunk/console/pom.xml
===================================================================
--- trunk/console/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/console/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -3,7 +3,7 @@
<parent>
<artifactId>teiid-parent</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
Modified: trunk/documentation/admin-guide/pom.xml
===================================================================
--- trunk/documentation/admin-guide/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/documentation/admin-guide/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -2,7 +2,7 @@
<parent>
<groupId>org.jboss.teiid</groupId>
<artifactId>documentation</artifactId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>admin-guide</artifactId>
Modified: trunk/documentation/caching-guide/pom.xml
===================================================================
--- trunk/documentation/caching-guide/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/documentation/caching-guide/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -2,7 +2,7 @@
<parent>
<groupId>org.jboss.teiid</groupId>
<artifactId>documentation</artifactId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>caching-guide</artifactId>
Modified: trunk/documentation/client-developers-guide/pom.xml
===================================================================
--- trunk/documentation/client-developers-guide/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/documentation/client-developers-guide/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -2,7 +2,7 @@
<parent>
<groupId>org.jboss.teiid</groupId>
<artifactId>documentation</artifactId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>client-developers-guide</artifactId>
Modified: trunk/documentation/developer-guide/pom.xml
===================================================================
--- trunk/documentation/developer-guide/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/documentation/developer-guide/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -2,7 +2,7 @@
<parent>
<groupId>org.jboss.teiid</groupId>
<artifactId>documentation</artifactId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>developer-guide</artifactId>
Modified: trunk/documentation/pom.xml
===================================================================
--- trunk/documentation/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/documentation/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -2,7 +2,7 @@
<parent>
<artifactId>teiid-parent</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<groupId>org.jboss.teiid</groupId>
Modified: trunk/documentation/quick-start-example/pom.xml
===================================================================
--- trunk/documentation/quick-start-example/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/documentation/quick-start-example/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -2,7 +2,7 @@
<parent>
<groupId>org.jboss.teiid</groupId>
<artifactId>documentation</artifactId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>quick-start-example</artifactId>
Modified: trunk/documentation/reference/pom.xml
===================================================================
--- trunk/documentation/reference/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/documentation/reference/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -2,7 +2,7 @@
<parent>
<groupId>org.jboss.teiid</groupId>
<artifactId>documentation</artifactId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>reference</artifactId>
Modified: trunk/engine/pom.xml
===================================================================
--- trunk/engine/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/engine/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -3,7 +3,7 @@
<parent>
<artifactId>teiid-parent</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>teiid-engine</artifactId>
Modified: trunk/hibernate-dialect/pom.xml
===================================================================
--- trunk/hibernate-dialect/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/hibernate-dialect/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -2,7 +2,7 @@
<parent>
<artifactId>teiid-parent</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>teiid-hibernate-dialect</artifactId>
Modified: trunk/jboss-integration/pom.xml
===================================================================
--- trunk/jboss-integration/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/jboss-integration/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -2,7 +2,7 @@
<parent>
<artifactId>teiid-parent</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<groupId>org.jboss.teiid</groupId>
Modified: trunk/metadata/pom.xml
===================================================================
--- trunk/metadata/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/metadata/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -3,7 +3,7 @@
<parent>
<artifactId>teiid-parent</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>teiid-metadata</artifactId>
Modified: trunk/pom.xml
===================================================================
--- trunk/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -5,15 +5,15 @@
<artifactId>teiid-parent</artifactId>
<packaging>pom</packaging>
<name>Teiid</name>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
<description>Federated SQL and XML query engine.</description>
<properties>
<ant.version>1.7.0</ant.version>
<site.url>http://www.jboss.org/teiid</site.url>
</properties>
<scm>
- <connection>scm:svn:https://anonsvn.jboss.org/repos/teiid/tags/teiid-parent-7.3.0.CR1</connection>
- <developerConnection>scm:svn:https://svn.jboss.org/repos/teiid/tags/teiid-parent-7.3.0.CR1</developerConnection>
+ <connection>scm:svn:https://anonsvn.jboss.org/repos/teiid/trunk</connection>
+ <developerConnection>scm:svn:https://svn.jboss.org/repos/teiid/trunk</developerConnection>
</scm>
<licenses>
<license>
Modified: trunk/runtime/pom.xml
===================================================================
--- trunk/runtime/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/runtime/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -3,7 +3,7 @@
<parent>
<artifactId>teiid-parent</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<groupId>org.jboss.teiid</groupId>
Modified: trunk/test-integration/common/pom.xml
===================================================================
--- trunk/test-integration/common/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/test-integration/common/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -3,7 +3,7 @@
<parent>
<artifactId>teiid-test-integration</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>test-integration-common</artifactId>
Modified: trunk/test-integration/db/pom.xml
===================================================================
--- trunk/test-integration/db/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/test-integration/db/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -9,7 +9,7 @@
<parent>
<artifactId>teiid-test-integration</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
Modified: trunk/test-integration/pom.xml
===================================================================
--- trunk/test-integration/pom.xml 2011-01-19 17:13:00 UTC (rev 2855)
+++ trunk/test-integration/pom.xml 2011-01-19 17:13:44 UTC (rev 2856)
@@ -3,7 +3,7 @@
<parent>
<artifactId>teiid-parent</artifactId>
<groupId>org.jboss.teiid</groupId>
- <version>7.3.0.CR1</version>
+ <version>7.3.0.CR2-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
<artifactId>teiid-test-integration</artifactId>
15 years, 2 months
--- branches/7.1.x/engine/src/test/java/org/teiid/query/unittest/RealMetadataFactory.java 2011-01-20 21:09:35 UTC (rev 2864)
+++ branches/7.1.x/engine/src/test/java/org/teiid/query/unittest/RealMetadataFactory.java 2011-01-21 00:55:36 UTC (rev 2865)
@@ -572,12 +572,13 @@
* @param name Name of procedure, must match model name
* @param model Metadata object for the model
* @param params List of FakeMetadataObject that are the parameters for the procedure
* @param callableName Callable name of procedure, usually same as procedure name
* @return Metadata object for stored procedure
*/
- public static Procedure createStoredProcedure(String name, Schema model, List<ProcedureParameter> params, String callableName) {
+ public static Procedure createStoredProcedure(String name, Schema model, List<ProcedureParameter> params, String nameInSource) {
Procedure proc = new Procedure();
proc.setName(name);
+ proc.setNameInSource(nameInSource);
if (params != null) {
int index = 1;
for (ProcedureParameter procedureParameter : params) {
@@ -572,12 +572,13 @@
* @param model Metadata object for the model
* @param params List of FakeMetadataObject that are the parameters for the procedure
- * @param callableName Callable name of procedure, usually same as procedure name
+ * @param nameInSource Callable name of procedure, usually same as procedure name
* @return Metadata object for stored procedure
*/
15 years, 2 months
teiid SVN: r2864 - in branches/7.1.x/connectors/translator-salesforce/src: test/java/org/teiid/translator/salesforce/execution and 1 other directories.
by teiid-commits@lists.jboss.org
Author: shawkins
Date: 2011-01-20 16:09:35 -0500 (Thu, 20 Jan 2011)
New Revision: 2864
Added:
branches/7.1.x/connectors/translator-salesforce/src/test/java/org/teiid/translator/salesforce/execution/TestProcedureExecution.java
Modified:
branches/7.1.x/connectors/translator-salesforce/src/main/java/org/teiid/translator/salesforce/execution/ProcedureExecutionParentImpl.java
branches/7.1.x/connectors/translator-salesforce/src/test/java/org/teiid/translator/salesforce/execution/visitors/TestVisitors.java
Log:
TEIID-1443 adding a better check for getupdated/getdeleted
Modified: branches/7.1.x/connectors/translator-salesforce/src/main/java/org/teiid/translator/salesforce/execution/ProcedureExecutionParentImpl.java
===================================================================
--- branches/7.3.x/engine/src/test/java/org/teiid/query/unittest/RealMetadataFactory.java 2011-01-20 15:28:34 UTC (rev 2862)
+++ branches/7.3.x/engine/src/test/java/org/teiid/query/unittest/RealMetadataFactory.java 2011-01-20 19:57:51 UTC (rev 2863)
@@ -604,12 +604,13 @@
* @param name Name of procedure, must match model name
* @param model Metadata object for the model
* @param params List of FakeMetadataObject that are the parameters for the procedure
* @param callableName Callable name of procedure, usually same as procedure name
* @return Metadata object for stored procedure
*/
- public static Procedure createStoredProcedure(String name, Schema model, List<ProcedureParameter> params, String callableName) {
+ public static Procedure createStoredProcedure(String name, Schema model, List<ProcedureParameter> params, String nameInSource) {
Procedure proc = new Procedure();
proc.setName(name);
+ proc.setNameInSource(nameInSource);
if (params != null) {
int index = 1;
for (ProcedureParameter procedureParameter : params) {
@@ -604,12 +604,13 @@
* @param model Metadata object for the model
* @param params List of FakeMetadataObject that are the parameters for the procedure
- * @param callableName Callable name of procedure, usually same as procedure name
+ * @param nameInSource Callable name of procedure, usually same as procedure name
* @return Metadata object for stored procedure
*/
15 years, 2 months
teiid SVN: r2862 - branches/7.1.x/console/src/main/resources/META-INF.
by teiid-commits@lists.jboss.org
Author: shawkins
Date: 2011-01-20 10:28:34 -0500 (Thu, 20 Jan 2011)
New Revision: 2862
Modified:
branches/7.1.x/console/src/main/resources/META-INF/rhq-plugin.xml
Log:
TEIID-1444 fixing mat view text
Modified: branches/7.1.x/console/src/main/resources/META-INF/rhq-plugin.xml
===================================================================